==> sparkautomapper.fhir-1.0.18.tar.gz: sparkautomapper.fhir-1.0.18/spark_auto_mapper_fhir/resources/consent.py <==
from __future__ import annotations
from typing import List, Optional, TYPE_CHECKING, Union

# noinspection PyPackageRequirements
from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.date_time import FhirDateTime
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.complex_types.meta import Meta
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_resource_base import FhirResourceBase
from spark_fhir_schemas.r4.resources.consent import ConsentSchema

if TYPE_CHECKING:
    pass
    # id_ (id)
    # meta (Meta)
    # implicitRules (uri)
    # language (CommonLanguages)
    from spark_auto_mapper_fhir.value_sets.common_languages import CommonLanguagesCode

    # text (Narrative)
    from spark_auto_mapper_fhir.complex_types.narrative import Narrative

    # contained (ResourceContainer)
    from spark_auto_mapper_fhir.complex_types.resource_container import (
        ResourceContainer,
    )

    # extension (Extension)
    # modifierExtension (Extension)
    # identifier (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # status (ConsentState)
    from spark_auto_mapper_fhir.value_sets.consent_state import ConsentStateCode

    # scope (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # Import for CodeableConcept for scope
    from spark_auto_mapper_fhir.value_sets.consent_scope_codes import (
        ConsentScopeCodesCode,
    )

    # End Import for CodeableConcept for scope
    # category (CodeableConcept)
    # Import for CodeableConcept for category
    from spark_auto_mapper_fhir.value_sets.consent_category_codes import (
        ConsentCategoryCodesCode,
    )

    # End Import for CodeableConcept for category
    # patient (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for patient
    from spark_auto_mapper_fhir.resources.patient import Patient

    # dateTime (dateTime)
    # performer (Reference)
    # Imports for References for performer
    from spark_auto_mapper_fhir.resources.organization import Organization
    from spark_auto_mapper_fhir.resources.practitioner import Practitioner
    from spark_auto_mapper_fhir.resources.related_person import RelatedPerson
    from spark_auto_mapper_fhir.resources.practitioner_role import PractitionerRole

    # organization (Reference)
    # Imports for References for organization
    # sourceAttachment (Attachment)
    from spark_auto_mapper_fhir.complex_types.attachment import Attachment

    # sourceReference (Reference)
    # Imports for References for sourceReference
    from spark_auto_mapper_fhir.resources.document_reference import DocumentReference
    from spark_auto_mapper_fhir.resources.contract import Contract
    from spark_auto_mapper_fhir.resources.questionnaire_response import (
        QuestionnaireResponse,
    )

    # policy (Consent.Policy)
    from spark_auto_mapper_fhir.backbone_elements.consent_policy import ConsentPolicy

    # policyRule (CodeableConcept)
    # Import for CodeableConcept for policyRule
    from spark_auto_mapper_fhir.value_sets.consent_policy_rule_codes import (
        ConsentPolicyRuleCodesCode,
    )

    # End Import for CodeableConcept for policyRule
    # verification (Consent.Verification)
    from spark_auto_mapper_fhir.backbone_elements.consent_verification import (
        ConsentVerification,
    )

    # provision (Consent.Provision)
    from spark_auto_mapper_fhir.backbone_elements.consent_provision import (
        ConsentProvision,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class Consent(FhirResourceBase):
    """
    Consent
    consent.xsd
        A record of a healthcare consumer’s  choices, which permits or denies
    identified recipient(s) or recipient role(s) to perform one or more actions
    within a given policy context, for specific purposes and periods of time.
        If the element is present, it must have either a @value, an @id, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        meta: Optional[Meta] = None,
        implicitRules: Optional[FhirUri] = None,
        language: Optional[CommonLanguagesCode] = None,
        text: Optional[Narrative] = None,
        contained: Optional[FhirList[ResourceContainer]] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        identifier: Optional[FhirList[Identifier]] = None,
        status: ConsentStateCode,
        scope: CodeableConcept[ConsentScopeCodesCode],
        category: FhirList[CodeableConcept[ConsentCategoryCodesCode]],
        patient: Optional[Reference[Patient]] = None,
        dateTime: Optional[FhirDateTime] = None,
        performer: Optional[
            FhirList[
                Reference[
                    Union[
                        Organization,
                        Patient,
                        Practitioner,
                        RelatedPerson,
                        PractitionerRole,
                    ]
                ]
            ]
        ] = None,
        organization: Optional[FhirList[Reference[Organization]]] = None,
        sourceAttachment: Optional[Attachment] = None,
        sourceReference: Optional[
            Reference[
                Union[Consent, DocumentReference, Contract, QuestionnaireResponse]
            ]
        ] = None,
        policy: Optional[FhirList[ConsentPolicy]] = None,
        policyRule: Optional[CodeableConcept[ConsentPolicyRuleCodesCode]] = None,
        verification: Optional[FhirList[ConsentVerification]] = None,
        provision: Optional[ConsentProvision] = None,
    ) -> None:
        """
            A record of a healthcare consumer’s  choices, which permits or denies
        identified recipient(s) or recipient role(s) to perform one or more actions
        within a given policy context, for specific purposes and periods of time.
            If the element is present, it must have either a @value, an @id, or extensions

            :param id_: The logical id of the resource, as used in the URL for the resource. Once
        assigned, this value never changes.
            :param meta: The metadata about the resource. This is content that is maintained by the
        infrastructure. Changes to the content might not always be associated with
        version changes to the resource.
            :param implicitRules: A reference to a set of rules that were followed when the resource was
        constructed, and which must be understood when processing the content. Often,
        this is a reference to an implementation guide that defines the special rules
        along with other profiles etc.
            :param language: The base language in which the resource is written.
            :param text: A human-readable narrative that contains a summary of the resource and can be
        used to represent the content of the resource to a human. The narrative need
        not encode all the structured data, but is required to contain sufficient
        detail to make it "clinically safe" for a human to just read the narrative.
        Resource definitions may define what content should be represented in the
        narrative to ensure clinical safety.
            :param contained: These resources do not have an independent existence apart from the resource
        that contains them - they cannot be identified independently, and nor can they
        have their own independent transaction scope.
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the resource. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the resource and that modifies the understanding of the element
        that contains it and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer is allowed to define an extension, there is a set of requirements
        that SHALL be met as part of the definition of the extension. Applications
        processing a resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param identifier: Unique identifier for this copy of the Consent Statement.
            :param status: Indicates the current state of this consent.
            :param scope: A selector of the type of consent being presented: ADR, Privacy, Treatment,
        Research.  This list is now extensible.
            :param category: A classification of the type of consents found in the statement. This element
        supports indexing and retrieval of consent statements.
            :param patient: The patient/healthcare consumer to whom this consent applies.
            :param dateTime: When this  Consent was issued / created / indexed.
            :param performer: Either the Grantor, which is the entity responsible for granting the rights
        listed in a Consent Directive or the Grantee, which is the entity responsible
        for complying with the Consent Directive, including any obligations or
        limitations on authorizations and enforcement of prohibitions.
            :param organization: The organization that manages the consent, and the framework within which it
        is executed.
            :param sourceAttachment: None
            :param sourceReference: None
            :param policy: The references to the policies that are included in this consent scope.
        Policies may be organizational, but are often defined jurisdictionally, or in
        law.
            :param policyRule: A reference to the specific base computable regulation or policy.
            :param verification: Whether a treatment instruction (e.g. artificial respiration yes or no) was
        verified with the patient, his/her family or another authorized person.
            :param provision: An exception to the base policy of this consent. An exception can be an
        addition or removal of access permissions.
        """
        super().__init__(
            resourceType="Consent",
            id_=id_,
            meta=meta,
            implicitRules=implicitRules,
            language=language,
            text=text,
            contained=contained,
            extension=extension,
            modifierExtension=modifierExtension,
            identifier=identifier,
            status=status,
            scope=scope,
            category=category,
            patient=patient,
            dateTime=dateTime,
            performer=performer,
            organization=organization,
            sourceAttachment=sourceAttachment,
            sourceReference=sourceReference,
            policy=policy,
            policyRule=policyRule,
            verification=verification,
            provision=provision,
        )

    def get_schema(
        self, include_extension: bool, extension_fields: Optional[List[str]] = None
    ) -> Optional[Union[StructType, DataType]]:
        return ConsentSchema.get_schema(
            include_extension=include_extension, extension_fields=extension_fields
        )

==> sparkautomapper.fhir-2.0.0.tar.gz: sparkautomapper.fhir-2.0.0/spark_auto_mapper_fhir/resources/consent.py <==
from __future__ import annotations
from typing import List, Optional, TYPE_CHECKING, Union

# noinspection PyPackageRequirements
from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.date_time import FhirDateTime
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.complex_types.meta import Meta
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_resource_base import FhirResourceBase
from spark_fhir_schemas.r4.resources.consent import ConsentSchema

if TYPE_CHECKING:
    pass
    # id_ (id)
    # meta (Meta)
    # implicitRules (uri)
    # language (CommonLanguages)
    from spark_auto_mapper_fhir.value_sets.common_languages import CommonLanguagesCode

    # text (Narrative)
    from spark_auto_mapper_fhir.complex_types.narrative import Narrative

    # contained (ResourceContainer)
    from spark_auto_mapper_fhir.complex_types.resource_container import (
        ResourceContainer,
    )

    # extension (Extension)
    # modifierExtension (Extension)
    # identifier (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # status (ConsentState)
    from spark_auto_mapper_fhir.value_sets.consent_state import ConsentStateCode

    # scope (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # Import for CodeableConcept for scope
    from spark_auto_mapper_fhir.value_sets.consent_scope_codes import (
        ConsentScopeCodesCode,
    )

    # End Import for CodeableConcept for scope
    # category (CodeableConcept)
    # Import for CodeableConcept for category
    from spark_auto_mapper_fhir.value_sets.consent_category_codes import (
        ConsentCategoryCodesCode,
    )

    # End Import for CodeableConcept for category
    # patient (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for patient
    from spark_auto_mapper_fhir.resources.patient import Patient

    # dateTime (dateTime)
    # performer (Reference)
    # Imports for References for performer
    from spark_auto_mapper_fhir.resources.organization import Organization
    from spark_auto_mapper_fhir.resources.practitioner import Practitioner
    from spark_auto_mapper_fhir.resources.related_person import RelatedPerson
    from spark_auto_mapper_fhir.resources.practitioner_role import PractitionerRole

    # organization (Reference)
    # Imports for References for organization
    # sourceAttachment (Attachment)
    from spark_auto_mapper_fhir.complex_types.attachment import Attachment

    # sourceReference (Reference)
    # Imports for References for sourceReference
    from spark_auto_mapper_fhir.resources.document_reference import DocumentReference
    from spark_auto_mapper_fhir.resources.contract import Contract
    from spark_auto_mapper_fhir.resources.questionnaire_response import (
        QuestionnaireResponse,
    )

    # policy (Consent.Policy)
    from spark_auto_mapper_fhir.backbone_elements.consent_policy import ConsentPolicy

    # policyRule (CodeableConcept)
    # Import for CodeableConcept for policyRule
    from spark_auto_mapper_fhir.value_sets.consent_policy_rule_codes import (
        ConsentPolicyRuleCodesCode,
    )

    # End Import for CodeableConcept for policyRule
    # verification (Consent.Verification)
    from spark_auto_mapper_fhir.backbone_elements.consent_verification import (
        ConsentVerification,
    )

    # provision (Consent.Provision)
    from spark_auto_mapper_fhir.backbone_elements.consent_provision import (
        ConsentProvision,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class Consent(FhirResourceBase):
    """
    Consent
    consent.xsd
        A record of a healthcare consumer’s  choices, which permits or denies
    identified recipient(s) or recipient role(s) to perform one or more actions
    within a given policy context, for specific purposes and periods of time.
        If the element is present, it must have either a @value, an @id, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        use_date_for: Optional[List[str]] = None,
        id_: Optional[FhirId] = None,
        meta: Optional[Meta] = None,
        implicitRules: Optional[FhirUri] = None,
        language: Optional[CommonLanguagesCode] = None,
        text: Optional[Narrative] = None,
        contained: Optional[FhirList[ResourceContainer]] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        identifier: Optional[FhirList[Identifier]] = None,
        status: ConsentStateCode,
        scope: CodeableConcept[ConsentScopeCodesCode],
        category: FhirList[CodeableConcept[ConsentCategoryCodesCode]],
        patient: Optional[Reference[Patient]] = None,
        dateTime: Optional[FhirDateTime] = None,
        performer: Optional[
            FhirList[
                Reference[
                    Union[
                        Organization,
                        Patient,
                        Practitioner,
                        RelatedPerson,
                        PractitionerRole,
                    ]
                ]
            ]
        ] = None,
        organization: Optional[FhirList[Reference[Organization]]] = None,
        sourceAttachment: Optional[Attachment] = None,
        sourceReference: Optional[
            Reference[
                Union[Consent, DocumentReference, Contract, QuestionnaireResponse]
            ]
        ] = None,
        policy: Optional[FhirList[ConsentPolicy]] = None,
        policyRule: Optional[CodeableConcept[ConsentPolicyRuleCodesCode]] = None,
        verification: Optional[FhirList[ConsentVerification]] = None,
        provision: Optional[ConsentProvision] = None,
    ) -> None:
        """
            A record of a healthcare consumer’s  choices, which permits or denies
        identified recipient(s) or recipient role(s) to perform one or more actions
        within a given policy context, for specific purposes and periods of time.
            If the element is present, it must have either a @value, an @id, or extensions

            :param id_: The logical id of the resource, as used in the URL for the resource. Once
        assigned, this value never changes.
            :param meta: The metadata about the resource. This is content that is maintained by the
        infrastructure. Changes to the content might not always be associated with
        version changes to the resource.
            :param implicitRules: A reference to a set of rules that were followed when the resource was
        constructed, and which must be understood when processing the content. Often,
        this is a reference to an implementation guide that defines the special rules
        along with other profiles etc.
            :param language: The base language in which the resource is written.
            :param text: A human-readable narrative that contains a summary of the resource and can be
        used to represent the content of the resource to a human. The narrative need
        not encode all the structured data, but is required to contain sufficient
        detail to make it "clinically safe" for a human to just read the narrative.
        Resource definitions may define what content should be represented in the
        narrative to ensure clinical safety.
            :param contained: These resources do not have an independent existence apart from the resource
        that contains them - they cannot be identified independently, and nor can they
        have their own independent transaction scope.
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the resource. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the resource and that modifies the understanding of the element
        that contains it and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer is allowed to define an extension, there is a set of requirements
        that SHALL be met as part of the definition of the extension. Applications
        processing a resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param identifier: Unique identifier for this copy of the Consent Statement.
            :param status: Indicates the current state of this consent.
            :param scope: A selector of the type of consent being presented: ADR, Privacy, Treatment,
        Research.  This list is now extensible.
            :param category: A classification of the type of consents found in the statement. This element
        supports indexing and retrieval of consent statements.
            :param patient: The patient/healthcare consumer to whom this consent applies.
            :param dateTime: When this  Consent was issued / created / indexed.
            :param performer: Either the Grantor, which is the entity responsible for granting the rights
        listed in a Consent Directive or the Grantee, which is the entity responsible
        for complying with the Consent Directive, including any obligations or
        limitations on authorizations and enforcement of prohibitions.
            :param organization: The organization that manages the consent, and the framework within which it
        is executed.
            :param sourceAttachment: None
            :param sourceReference: None
            :param policy: The references to the policies that are included in this consent scope.
        Policies may be organizational, but are often defined jurisdictionally, or in
        law.
            :param policyRule: A reference to the specific base computable regulation or policy.
            :param verification: Whether a treatment instruction (e.g. artificial respiration yes or no) was
        verified with the patient, his/her family or another authorized person.
            :param provision: An exception to the base policy of this consent. An exception can be an
        addition or removal of access permissions.
        """
        super().__init__(
            resourceType="Consent",
            id_=id_,
            meta=meta,
            implicitRules=implicitRules,
            language=language,
            text=text,
            contained=contained,
            extension=extension,
            modifierExtension=modifierExtension,
            identifier=identifier,
            status=status,
            scope=scope,
            category=category,
            patient=patient,
            dateTime=dateTime,
            performer=performer,
            organization=organization,
            sourceAttachment=sourceAttachment,
            sourceReference=sourceReference,
            policy=policy,
            policyRule=policyRule,
            verification=verification,
            provision=provision,
        )

        self.use_date_for = use_date_for

    def get_schema(
        self, include_extension: bool, extension_fields: Optional[List[str]] = None
    ) -> Optional[Union[StructType, DataType]]:
        return ConsentSchema.get_schema(
            include_extension=include_extension,
            extension_fields=extension_fields,
            use_date_for=self.use_date_for,
        )
